@@ -226,8 +226,10 @@ def deploy_remote_core():
         rsync_argument += ' -v'
     elif verbose_level == 3:
         rsync_argument += ' -Pv'
-    target = 'beanstalk@%s:%s' % (host_name, remote_source_path)
-    local(rsync(env.temp_directory, target, rsync_argument=rsync_argument, expand_to_destination=True))
+    target_source_path = 'beanstalk@%s:%s' % (host_name, remote_source_path)
+    target_base_path = 'beanstalk@%s:%s' % (host_name, remote_base_path)
+    local(rsync(env.temp_directory, target_source_path, rsync_argument=rsync_argument, expand_to_destination=True))
+    local(rsync('%s/.gitignore' % env.temp_directory, target_base_path))
 
     # Call post-install script
     run_hooked_actions('POST_RSYNC_ACTIONS')
@@ -241,6 +243,5 @@ def deploy_remote_core():
 
     # Commit state to git repo
     print section_title('Commit current code to git repo')
-    run('bsjack server.commit_app:%s,processes=%d,threads=%d,VERBOSE=%d --hide=status' %
-        (project_name, beanstalk_settings['PROCESSES'], beanstalk_settings['THREADS'], beanstalk_settings['VERBOSE']))
+    run('bsjack server.commit_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
     run('bsjack server.reload_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
