@@ -1,3 +1,4 @@
+import ConfigParser
 import datetime
 import json
 import os
@@ -313,6 +314,35 @@ def update_app(project_name, settings_path=None, **settings_patches):
     local('find %s -name \'*.pyo\' -exec rm -rf {} \;' % project_source)
     local('python -m compileall -q %s' % project_source)
 
+    print section_title('Setup uwsgi')
+    # uwsgi port
+    try:
+        uwsgi_port = int([name for name in os.listdir(project_base_path(project_name))
+                          if name.endswith('.port')][0].split('.')[0])
+    except (IndexError, ValueError):
+        abort('No port number!?')
+        return
+    # edit ini
+    uwsgi_path = os.path.join(project_source_path(project_name), 'uwsgi.ini')
+    config = ConfigParser.ConfigParser()
+    if os.path.exists(uwsgi_path):
+        config.read(uwsgi_path)
+    else:
+        config.set('uwsgi', 'master', True)
+        config.set('uwsgi', 'enable-threads', True)
+        config.set('uwsgi', 'threads', 20)
+        config.set('uwsgi', 'processes', 4)
+        config.set('uwsgi', 'module', '%s.wsgi:application' % project_name)
+    config.set('uwsgi', 'socket', '127.0.0.1:%d' % uwsgi_port)
+    config.set('uwsgi', 'chdir', project_source_path(project_name))
+    config.set('uwsgi', 'home', project_venv_path(project_name))
+    with hide('everything'):
+        uid = local('id -u beanstalk', capture=True)
+    config.set('uwsgi', 'uid', uid)
+    config.set('uwsgi', 'logto', project_logs_path(project_name))
+    with open(uwsgi_path, 'wb') as f:
+        config.write(f)
+
 
 @task
 @beanstalk_role('server')
@@ -425,7 +455,7 @@ def list_apps(settings_path=None, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def commit_app(project_name, processes=2, threads=20, settings_path=None, **settings_patches):
+def commit_app(project_name, settings_path=None, **settings_patches):
     """Get list of apps
     """
     settings_patches = eval_kwargs(settings_patches)
